New Relic OpenCensus Exporters
==============================

This library provides Python `OpenCensus`_ exporter classes. These classes can be
used to send span and metric data to New Relic from `OpenCensus`_.

.. _OpenCensus: https://opencensus.io

Get Started!
------------

.. toctree::
   :maxdepth: 2

   quickstart

API Reference
-------------

.. toctree::
   :maxdepth: 2

   api
